@@ -33,9 +33,10 @@
 #  define KNOTIFYCONFIG_DEPRECATED_NO_EXPORT KNOTIFYCONFIG_NO_EXPORT KNOTIFYCONFIG_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KNOTIFYCONFIG_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KNOTIFYCONFIG_NO_DEPRECATED
+#    define KNOTIFYCONFIG_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
